#!/usr/bin/env python
###############################################################################
# $Id: tiff_write.py,v 1.7 2005/12/11 21:21:39 fwarmerdam Exp $
#
# Project:  GDAL/OGR Test Suite
# Purpose:  Test that downsampling in rasterio works properly.
# Author:   Frank Warmerdam <warmerdam@pobox.com>
# 
###############################################################################
# Copyright (c) 2006, Frank Warmerdam <warmerdam@pobox.com>
# 
# This library is free software; you can redistribute it and/or
# modify it under the terms of the GNU Library General Public
# License as published by the Free Software Foundation; either
# version 2 of the License, or (at your option) any later version.
# 
# This library is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# Library General Public License for more details.
# 
# You should have received a copy of the GNU Library General Public
# License along with this library; if not, write to the
# Free Software Foundation, Inc., 59 Temple Place - Suite 330,
# Boston, MA 02111-1307, USA.
###############################################################################
# 
#  $Log: tiff_write.py,v $
#

import os
import sys
import gdal
import string

sys.path.append( '../pymod' )

import gdaltest

###############################################################################
# For the cache size to zero, so that things are flushed as soon as they
# are unlocked.

def smallcache_1():

    gdaltest.orig_cachemax = gdal.GetCacheMax()
    gdal.SetCacheMax( 0 )

    if gdal.GetCacheUsed() > 0:
        gdaltest.post_reason( 'cache not flushing to zero.' )
        return 'fail'
    
    return 'success'

###############################################################################
# Translate to block oriented file. 

def smallcache_2():

    ut = gdaltest.GDALTest( 'HFA', 'utmsmall.tif', 1, 50054 )

    return ut.testCreate()

###############################################################################
# translate to line oriented file.

def smallcache_3():

    ut = gdaltest.GDALTest( 'GTiff', 'utmsmall.tif', 1, 50054 )

    return ut.testCreate()

###############################################################################
# Translate line oriented data to block oriented file (createcopy)

def smallcache_4():

    ut = gdaltest.GDALTest( 'HFA', 'utmsmall.tif', 1, 50054 )

    return ut.testCreateCopy()

###############################################################################
# Do block oriented to line oriented (createcopy)

def smallcache_5():

    ut = gdaltest.GDALTest( 'GTiff', 'utmsmall.img', 1, 50054 )

    return ut.testCreateCopy()

###############################################################################
# Translate line oriented data to block oriented file. 

def smallcache_cleanup():

    gdal.SetCacheMax( gdaltest.orig_cachemax )

    return 'success'

gdaltest_list = [
    smallcache_1,
    smallcache_2,
#    smallcache_3,
#    smallcache_4,
#    smallcache_5,
#    smallcache_6,
#    smallcache_7,
#    smallcache_8,
    smallcache_cleanup ]

if __name__ == '__main__':

    gdaltest.setup_run( 'smallcache' )

    gdaltest.run_tests( gdaltest_list )

    gdaltest.summarize()

