#!/usr/bin/env python
###############################################################################
# $Id: idrisi.py,v 1.2 2006/03/31 05:19:21 fwarmerdam Exp $
#
# Project:  GDAL/OGR Test Suite
# Purpose:  Test read/write functionality for RST/Idrisi driver.
# Author:   Frank Warmerdam <warmerdam@pobox.com>
# 
###############################################################################
# Copyright (c) 2006, Frank Warmerdam <warmerdam@pobox.com>
# 
# This library is free software; you can redistribute it and/or
# modify it under the terms of the GNU Library General Public
# License as published by the Free Software Foundation; either
# version 2 of the License, or (at your option) any later version.
# 
# This library is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# Library General Public License for more details.
# 
# You should have received a copy of the GNU Library General Public
# License along with this library; if not, write to the
# Free Software Foundation, Inc., 59 Temple Place - Suite 330,
# Boston, MA 02111-1307, USA.
###############################################################################
# 
#  $Log: idrisi.py,v $
#  Revision 1.2  2006/03/31 05:19:21  fwarmerdam
#  Cleanup properly.
#
#  Revision 1.1  2006/03/31 05:19:05  fwarmerdam
#  New
#
#
#

import os
import sys
import gdal

sys.path.append( '../pymod' )

import gdaltest

###############################################################################
# Read test of byte file.

def idrisi_1():

    tst = gdaltest.GDALTest( 'RST', 'byte.rst', 1, 5044 )
    return tst.testOpen()

###############################################################################
# Read test of byte file.

def idrisi_2():

    tst = gdaltest.GDALTest( 'RST', 'real.rst', 1, 5275 )
    return tst.testOpen()

###############################################################################
# 

def idrisi_3():

    tst = gdaltest.GDALTest( 'RST', 'float32.bil', 1, 27 )

    return tst.testCreate( new_filename = 'tmp/float32.rst', out_bands=1 )
    
###############################################################################
# 

def idrisi_4():

    tst = gdaltest.GDALTest( 'RST', 'rgbsmall.tif', 2, 21053 )

    return tst.testCreateCopy( check_gt = 1, check_srs = 1,
                               new_filename = 'tmp/rgbsmall_cc.rst' )
    
###############################################################################
# Cleanup.

def idrisi_cleanup():
    gdaltest.clean_tmp()
    return 'success'

gdaltest_list = [
    idrisi_1,
    idrisi_2,
    idrisi_3,
    idrisi_4,
    idrisi_cleanup ]

if __name__ == '__main__':

    gdaltest.setup_run( 'idrisi' )

    gdaltest.run_tests( gdaltest_list )

    gdaltest.summarize()

