#!/usr/bin/env python
###############################################################################
# $Id: osr_pm.py,v 1.1 2006/04/21 03:23:47 fwarmerdam Exp $
#
# Project:  GDAL/OGR Test Suite
# Purpose:  Test some prime meridian related issues with EPSG translation
#           and evaluation by PROJ.4.
# Author:   Frank Warmerdam <warmerdam@pobox.com>
# 
###############################################################################
# Copyright (c) 2003, Frank Warmerdam <warmerdam@pobox.com>
# 
# This library is free software; you can redistribute it and/or
# modify it under the terms of the GNU Library General Public
# License as published by the Free Software Foundation; either
# version 2 of the License, or (at your option) any later version.
# 
# This library is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# Library General Public License for more details.
# 
# You should have received a copy of the GNU Library General Public
# License along with this library; if not, write to the
# Free Software Foundation, Inc., 59 Temple Place - Suite 330,
# Boston, MA 02111-1307, USA.
###############################################################################
# 
#  $Log: osr_pm.py,v $
#  Revision 1.1  2006/04/21 03:23:47  fwarmerdam
#  New
#
#

import os
import sys

sys.path.append( '../pymod' )

import gdaltest
import osr
import string

###############################################################################
#	Check that EPSG:27572 lookup has the prime meridian properly set,
# 	and the central meridian.

def osr_pm_1():
    
    srs = osr.SpatialReference()
    srs.ImportFromEPSG( 27572 )

    if abs(float(srs.GetAttrValue( 'PRIMEM', 1))-2.33722917) > 0.0000005:
        gdaltest.post_reason( 'Wrong prime meridian.' )
        return 'fail'
    
    if abs(srs.GetProjParm( osr.SRS_PP_CENTRAL_MERIDIAN )-0.0) > 0.0000005:
        gdaltest.post_reason( 'Wrong central meridian.' )
        return 'fail'

    return 'success'

###############################################################################
#	Check that EPSG:27572 lookup has the prime meridian properly set,
# 	and the central meridian in the PROJ.4 string.

def osr_pm_2():
    
    srs = osr.SpatialReference()
    srs.ImportFromEPSG( 27572 )
    proj4_srs = srs.ExportToProj4()

    if string.find( proj4_srs, '+pm=paris' ) == -1:
        gdaltest.post_reason( 'prime meridian wrong or missing.' )
        return 'fail'
    
    if string.find( proj4_srs, '+lon_0=0' ) == -1:
        gdaltest.post_reason( '+lon_0 is wrong.' )
        return 'fail'
    
    return 'success'

###############################################################################
#	Convert PROJ.4 format to WKT and verify that PM and central meridian
#       are properly preserved.

def osr_pm_3():
    
    srs = osr.SpatialReference()
    srs.ImportFromProj4( '+proj=utm +zone=30 +datum=WGS84 +pm=bogota' )

    if abs(float(srs.GetAttrValue( 'PRIMEM', 1))+74.08091666678081) > 0.0000005:
        gdaltest.post_reason( 'Wrong prime meridian.' )
        return 'fail'

    if abs(srs.GetProjParm( osr.SRS_PP_CENTRAL_MERIDIAN )+3.0) > 0.0000005:
        gdaltest.post_reason( 'Wrong central meridian.' )
        return 'fail'

    return 'success'


###############################################################################

gdaltest_list = [ 
    osr_pm_1,
    osr_pm_2,
    osr_pm_3,
    None ]

if __name__ == '__main__':

    gdaltest.setup_run( 'osr_proj4' )

    gdaltest.run_tests( gdaltest_list )

    gdaltest.summarize()

